<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl_BE">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Kleuren</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Kleur5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Kleur6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Kleur7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Kleur8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Kleur9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="684"/>
        <source>Select Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="790"/>
        <source>Permission Denied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="791"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Write Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Cannot write to file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Backup Config File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Do you want to preserve the original file?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="897"/>
        <source>Backed Up Config File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="898"/>
        <source>The original configuration was backed up to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Backup Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Failed to create a backup file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Restore Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <source>Failed to restore from backup file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Backup file does not exist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1328"/>
        <source>Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
        <source>Alignment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1340"/>
        <source>Top Left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1341"/>
        <source>Top Right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
        <source>Top Middle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1343"/>
        <source>Bottom Left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1344"/>
        <source>Bottom Right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1345"/>
        <source>Bottom Middle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1346"/>
        <source>Middle Left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
        <source>Middle Right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
        <source>Middle Middle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
        <source>Horizontal Gap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1366"/>
        <source>Vertical Gap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1367"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1379"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1382"/>
        <source>Desktop 1</source>
        <translation>Desktop 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1383"/>
        <source>All Desktops</source>
        <translation>Alle Desktops</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1395"/>
        <source>Location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1407"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1411"/>
        <source>Minimum Width</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1426"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1428"/>
        <source>Minimum Height</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1442"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1443"/>
        <source>Height Padding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1458"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1471"/>
        <source>Transparency Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1476"/>
        <source>Opaque</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1477"/>
        <source>Transparent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
        <source>Pseudo-Transparent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1479"/>
        <source>Semi-Transparent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Opacity (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Background Color</source>
        <translation>Achtergrond kleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1504"/>
        <source>Choose Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1524"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1545"/>
        <source>Transparency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1556"/>
        <source>Date Format</source>
        <translation>Datumnotatie</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1559"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1561"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1572"/>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1562"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1573"/>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1563"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Afgekorte naam, bv. Di</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1570"/>
        <source>Month</source>
        <translation>Maand</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1574"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Afgekorte naam, bv. Okt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1593"/>
        <source>Time Format</source>
        <translation>Tijd formaat:</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1600"/>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1605"/>
        <source>12 Hour</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1606"/>
        <source>24 Hour</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1621"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Tijd</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1634"/>
        <source>Interface</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1642"/>
        <source>WiFi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1645"/>
        <source>WiFi Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1648"/>
        <source>LAN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1651"/>
        <source>Wired LAN Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1665"/>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1928"/>
        <source>Select Background Color</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="595"/>
        <source>Total: %1 conkies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="547"/>
        <source>No Conky Selected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="549"/>
        <source>Select a conky from the list to see its preview</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="568"/>
        <source>Preview image could not be loaded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>No preview image available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="57"/>
        <location filename="../src/mainwindow.cpp" line="829"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="249"/>
        <source>About this application</source>
        <translation>Over deze applicatie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="247"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="254"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="269"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="267"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>Loading Conky configurations...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>Configure conky search paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="191"/>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="193"/>
        <source>Refresh conky list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="195"/>
        <source>Start All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="197"/>
        <source>Start all enabled conkies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="199"/>
        <source>Stop All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="201"/>
        <source>Stop all running conkies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="931"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <location filename="../src/mainwindow.cpp" line="969"/>
        <source>Stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="209"/>
        <source>Search conky by name...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="211"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="256"/>
        <source>Display help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <location filename="../src/mainwindow.cpp" line="608"/>
        <source>Copy Conky</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="478"/>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky Copied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Copy Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="543"/>
        <source>Delete Conky</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="657"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Delete Successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>Previews</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Generate preview images for conkies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <location filename="../src/mainwindow.cpp" line="929"/>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <source>Filter conkies by running status or location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="428"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Enter a name for the copy:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="605"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>Directory Exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>Edit Conky</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Conky file deleted successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Delete Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Failed to delete conky file:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>Customize Conky</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="667"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Editor Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Cannot start editor for file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="828"/>
        <source>About MX Conky</source>
        <translation>Over MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="830"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="831"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>GUI programma voor configuratie van Conky in MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="836"/>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="837"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="859"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="890"/>
        <source>MX Conky Help</source>
        <translation>MX Conky Hulp</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="155"/>
        <source>Starting preview generation...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="159"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="198"/>
        <source>Generating preview for: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="419"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="423"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="426"/>
        <source>Preview Generation Complete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Successfully generated %1 preview images.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Selecteer Conky Beheer configuratiebestand</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>U moet dit programma als normale gebruiker uitvoeren</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Autostart Instellingen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
</TS>